{
    "id": "#main",
    "class": "Workflow",
    "requirements": [
        {
            "class": "InlineJavascriptRequirement"
        }
    ],
    "inputs": [
        {
            "id": "#main/vcf",
            "type": "File"
        },
        {
            "id": "#main/metadata_csv",
            "type": "File"
        }
    ],
    "steps": [
        {
            "id": "#main/parse_metadata",
            "in": [
                {
                    "id": "#main/parse_metadata/metadata_csv",
                    "source": "#main/metadata_csv"
                }
            ],
            "out": [
                {
                    "id": "#main/parse_metadata/covariates"
                },
                {
                    "id": "#main/parse_metadata/phenotypes"
                },
                {
                    "id": "#main/parse_metadata/sex"
                },
                {
                    "id": "#main/parse_metadata/ids"
                }
            ],
            "run": {
                "class": "CommandLineTool",
                "id": "#main/parse_metadata/run/parse_metadata",
                "inputs": [
                    {
                        "id": "#main/parse_metadata/run/parse_metadata/metadata_csv",
                        "type": "File"
                    }
                ],
                "outputs": [
                    {
                        "id": "#main/parse_metadata/run/parse_metadata/covariates",
                        "type": "File",
                        "outputBinding": {
                            "glob": "covariates.txt"
                        }
                    },
                    {
                        "id": "#main/parse_metadata/run/parse_metadata/phenotypes",
                        "type": "File",
                        "outputBinding": {
                            "glob": "phenotypes.txt"
                        }
                    },
                    {
                        "id": "#main/parse_metadata/run/parse_metadata/sex",
                        "type": "File",
                        "outputBinding": {
                            "glob": "sex.txt"
                        }
                    },
                    {
                        "id": "#main/parse_metadata/run/parse_metadata/ids",
                        "type": "File",
                        "outputBinding": {
                            "glob": "ids.txt"
                        }
                    }
                ],
                "requirements": [
                    {
                        "class": "InitialWorkDirRequirement",
                        "listing": [
                            {
                                "entryname": "script.bash",
                                "entry": "\nparse_metadata.sh \\\n\t-c $(inputs.metadata_csv.path)\n"
                            }
                        ]
                    },
                    {
                        "class": "InlineJavascriptRequirement"
                    },
                    {
                        "class": "NetworkAccess",
                        "networkAccess": true
                    }
                ],
                "hints": [
                    {
                        "class": "DockerRequirement",
                        "dockerPull": "dnastack/plink:1.9"
                    },
                    {
                        "class": "ResourceRequirement",
                        "coresMin": 1,
                        "ramMin": 3576.2786865234375,
                        "outdirMin": 20480
                    }
                ],
                "cwlVersion": "v1.2",
                "baseCommand": [
                    "bash",
                    "script.bash"
                ]
            }
        },
        {
            "id": "#main/run_gwas",
            "in": [
                {
                    "id": "#main/run_gwas/vcf",
                    "source": "#main/vcf"
                },
                {
                    "id": "#main/run_gwas/covariates",
                    "source": "#main/parse_metadata/covariates"
                },
                {
                    "id": "#main/run_gwas/phenotypes",
                    "source": "#main/parse_metadata/phenotypes"
                },
                {
                    "id": "#main/run_gwas/sex",
                    "source": "#main/parse_metadata/sex"
                },
                {
                    "id": "#main/run_gwas/ids",
                    "source": "#main/parse_metadata/ids"
                }
            ],
            "out": [
                {
                    "id": "#main/run_gwas/logistic"
                }
            ],
            "run": {
                "class": "CommandLineTool",
                "id": "#main/run_gwas/run/run_gwas",
                "inputs": [
                    {
                        "id": "#main/run_gwas/run/run_gwas/vcf",
                        "type": "File"
                    },
                    {
                        "id": "#main/run_gwas/run/run_gwas/covariates",
                        "type": "File"
                    },
                    {
                        "id": "#main/run_gwas/run/run_gwas/phenotypes",
                        "type": "File"
                    },
                    {
                        "id": "#main/run_gwas/run/run_gwas/sex",
                        "type": "File"
                    },
                    {
                        "id": "#main/run_gwas/run/run_gwas/ids",
                        "type": "File"
                    }
                ],
                "outputs": [
                    {
                        "id": "#main/run_gwas/run/run_gwas/logistic",
                        "type": "File",
                        "outputBinding": {
                            "glob": "$(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, '') + \".assoc.logistic\")"
                        }
                    }
                ],
                "requirements": [
                    {
                        "class": "InitialWorkDirRequirement",
                        "listing": [
                            {
                                "entryname": "script.bash",
                                "entry": "\nplink \\\n\t--vcf $(inputs.vcf.path) \\\n\t--maf 0.10 \\\n\t--update-ids $(inputs.ids.path) \\\n\t--make-bed \\\n\t--out $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, ''))\n\nplink \\\n\t--bfile $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, '')) \\\n\t--update-sex $(inputs.sex.path) \\\n\t--pheno $(inputs.phenotypes.path) \\\n\t--make-bed \\\n\t--out $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, ''))\n\n# Recode covariates to binary\nplink \\\n\t--bfile $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, '')) \\\n\t--covar $(inputs.covariates.path) \\\n\t--dummy-coding \\\n\t--write-covar\n\nplink \\\n\t--bfile $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, '')) \\\n\t--logistic \\\n\t--covar plink.cov \\\n\t--out $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, ''))\n\nsed -i -e 's/\\s\\+/,/g' -e 's/^,//g' -e 's/,$//g' $(inputs.vcf.path.replace(\"\\\\?.*\", \"\") .split('/').reverse()[0].replace(/\\.vcf\\.gz$/, '')).assoc.logistic\n"
                            }
                        ]
                    },
                    {
                        "class": "InlineJavascriptRequirement"
                    },
                    {
                        "class": "NetworkAccess",
                        "networkAccess": true
                    }
                ],
                "hints": [
                    {
                        "class": "DockerRequirement",
                        "dockerPull": "dnastack/plink:1.9"
                    },
                    {
                        "class": "ResourceRequirement",
                        "coresMin": 4,
                        "ramMin": 15258.7890625,
                        "outdirMin": 358400
                    }
                ],
                "cwlVersion": "v1.2",
                "baseCommand": [
                    "bash",
                    "script.bash"
                ]
            }
        },
        {
            "id": "#main/create_plot",
            "in": [
                {
                    "id": "#main/create_plot/assoc_file",
                    "source": "#main/run_gwas/logistic"
                }
            ],
            "out": [
                {
                    "id": "#main/create_plot/manhattan_plot"
                }
            ],
            "run": {
                "class": "CommandLineTool",
                "id": "#main/create_plot/run/create_plot",
                "inputs": [
                    {
                        "id": "#main/create_plot/run/create_plot/assoc_file",
                        "type": "File"
                    }
                ],
                "outputs": [
                    {
                        "id": "#main/create_plot/run/create_plot/manhattan_plot",
                        "type": "File",
                        "outputBinding": {
                            "glob": "$(inputs.assoc_file.basename.replace(/\\.assoc\\.logistic$/, '')  + \".png\")"
                        }
                    }
                ],
                "requirements": [
                    {
                        "class": "InitialWorkDirRequirement",
                        "listing": [
                            {
                                "entryname": "script.bash",
                                "entry": "\nmanhattan_plot.py \\\n\t-i $(inputs.assoc_file.path) \\\n\t-o $(inputs.assoc_file.basename.replace(/\\.assoc\\.logistic$/, '') ).png\n"
                            }
                        ]
                    },
                    {
                        "class": "InlineJavascriptRequirement"
                    },
                    {
                        "class": "NetworkAccess",
                        "networkAccess": true
                    }
                ],
                "hints": [
                    {
                        "class": "DockerRequirement",
                        "dockerPull": "dnastack/plink:1.9"
                    },
                    {
                        "class": "ResourceRequirement",
                        "coresMin": 2,
                        "ramMin": 7152.557373046875,
                        "outdirMin": 20480
                    }
                ],
                "cwlVersion": "v1.2",
                "baseCommand": [
                    "bash",
                    "script.bash"
                ]
            }
        }
    ],
    "outputs": [
        {
            "id": "#main/gwas.logistic",
            "outputSource": "#main/run_gwas/logistic",
            "type": "File"
        },
        {
            "id": "#main/gwas.manhattan_plot",
            "outputSource": "#main/create_plot/manhattan_plot",
            "type": "File"
        }
    ],
    "cwlVersion": "v1.2"
}
